#!/usr/bin/env python3
#coding: utf-8

"""\
This scripts helps with detecting the plumes as described in D4.
"""

import matplotlib as mpl
mpl.use("Agg")

from multiprocessing import Pool
import os
import pandas
import sys
import matplotlib.pyplot as plt
import numpy as np

import smartcarb as sc


#TRACER = 'CO2'
#ERROR = float(sys.argv[3])
#USE_EPF = True
#BG_TYPE = 'model'


def main(i):

    # create input filenames
    d = pandas.read_csv("data/pixels_in_Berlin_plumes_clouds.dat", sep='\t')
    fnames = d['filename'][d['XCO2'] > 0].values
    input_path = '/scratch/snx3000/gkuhl/smartcarb/level2/Sentinel_7_CO2/'
    input_fnames = [os.path.join(input_path, fn) for fn in fnames]

    # create output filenames
    if USE_EPF:
        suffix = '_%s_%02d-epf_bg-%s.dat' % (TRACER, 10*ERROR, BG_TYPE)
    else:
        suffix = '_%s_%02d_bg-%s.dat' % (TRACER, 10*ERROR, BG_TYPE)


    output_path = '/users/gkuhl/projects/smartcarb/plume_detection/results'
    output_fnames = [os.path.join(output_path, fn.replace('.nc', suffix))
            for fn in fnames]

    print(fnames[i])
    sc.plume.main(input_fnames[i], output_fnames[i], TRACER, ERROR, USE_EPF,
            cloud_thr=0.01, bg_type=BG_TYPE)



def quick_labels(fnames, output_path):
    for fn in fnames:
        print(os.path.basename(fn))
        res = sc.plume.show_all_ground_truths(fn, output_path=output_path)
        if res:
            plt.close()



if __name__ == '__main__':
    level2_path = '/project/smartcarb/data1/level2/Sentinel_7_CO2/'
    origin = "Lippendorf"

    args = []

    for p_thr in [0.90, 0.95, 0.99]:#, 0.90, 0.95, 0.99]:

        for footprint in [1,5,9]:#1,5,9,16,25,37,49,81,121]:

            output_path = '/project/smartcarb/plume_detection/%s_v2/case_p%d_n%d' % (
                    origin, 100*p_thr, footprint)

            os.makedirs(output_path, exist_ok=True)

            tracer = 'NO2' #
            for error_std in ['S5']:# ['low', 'high']:
                for cloud_thr in [0.30]:#[0.01, 0.30]:
                    args.append([
                        output_path, level2_path, tracer, error_std,
                        origin, p_thr, footprint, cloud_thr, True
                    ])

        continue
        for footprint in [13]: #[1,5,9,13,25,37,49,81,121]:
            output_path = '/project/smartcarb/plume_detection/%s_v2/case_p%d_n%d' % (
                    origin, 100*p_thr, footprint)

            os.makedirs(output_path, exist_ok=True)

            tracer = 'NO2' # 2 cases
            for error_std in ['low', 'high']:
                for cloud_thr in [0.01, 0.30]:#[0.01, 0.30]:
                    args.append([
                        output_path, level2_path, tracer, error_std,
                        origin, p_thr, footprint, cloud_thr, False
                    ])

            tracer = 'CO2' # 3 cases
            for error_std in [0.5, 0.7, 1.0]:
                args.append([
                    output_path, level2_path, tracer, error_std,
                    origin, p_thr, footprint, 0.01, False
                ])


    with Pool(10) as pool:
        pool.starmap(sc.plume.main, args)


